pub enum WorkerBuilderError {
DuplicateHandler(String),
ReserveOptions(ReserveOptionsError),
}Expand description
Returned by the Worker builder methods on invalid configuration.
Variants
DuplicateHandler(String)
handle was called twice for the same job type. Use
replace_handler to overwrite intentionally.
ReserveOptions(ReserveOptionsError)
The underlying ReserveOptions were invalid (e.g. an empty queue or
worker id).